# utilities

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This repository provides basic utilities that might be handy when you contribute
your challenges, anonymizers or deanonymizers to the AnoMed platform. Mainly it
consists of …

- dataset preparation routines (regarding NumPy arrays)
- routines regarding web transmission of NumPy arrays
- building blocks for challenge/submission falcon apps
